photosgallery/viewframework/views/fullscreenview/inc/glxfullscreenviewimp.h
branchRCL_3
changeset 17 a60acebbbd9d
parent 15 191387a8b767
child 18 78ad99c24f08
--- a/photosgallery/viewframework/views/fullscreenview/inc/glxfullscreenviewimp.h	Tue Apr 27 16:37:53 2010 +0300
+++ b/photosgallery/viewframework/views/fullscreenview/inc/glxfullscreenviewimp.h	Tue May 11 16:13:40 2010 +0300
@@ -22,7 +22,7 @@
 #include <mglxuicommandhandler.h>
 #include <gesturehelper.h>
 #include <gestureobserver.h>
-
+#include <alf/alfcompositionutility.h>
 #include "glxfullscreenview.h"
 #include "glxfullscreenbindingsetfactory.h"
 #include "glxfullscreenview.hrh"
@@ -48,7 +48,6 @@
 class CGestureHelper;
 class TGlxMedia;
 class CGlxFullScreenBusyIcon;
-//class CHgContextUtility;
 
 namespace Alf
 	{
@@ -58,16 +57,6 @@
    class IMulSliderModel;
 	}
 /*
- Defines the state of the Ui in fullscreen
- */	
-namespace NGlxNFullScreenUIState
-    {
-    enum TUiState
-        {
-         EUiOn,EUiOff
-        };
-    }
-/*
  Defines the swipe direction
  */ 
 enum TSwipe
@@ -78,7 +67,8 @@
 NONSHARABLE_CLASS (CGlxFullScreenViewImp): public CGlxFullScreenView, 
                                             public IAlfWidgetEventHandler,
  											public MGlxUiCommandHandler,
-			                                public MStorageNotifierObserver
+			                                public MStorageNotifierObserver,
+			                                public CAlfEffectObserver::MAlfEffectObserver
     {
 public:    
     /**
@@ -144,8 +134,9 @@
     AlfEventHandlerType eventHandlerType() ;
 
     AlfEventHandlerExecutionPhase eventExecutionPhase() ;
-
-
+	
+	//From MAlfEffectObserver
+    void HandleEffectCallback(TInt aType, TInt aHandle, TInt aStatus);
 private:
     /*
      * Constructor 
@@ -203,21 +194,21 @@
     
     /*
     * Hide the UI off
     * @param asliderstatus:When we start zooming using the slider widget,for continous zooming from the 
     * fullscreen view to zoom control, we need to have the slider visible so in this case we shouldnt 
     * be hiding the slider so pass EFalse,else case asliderstatus = ETrue
     */     
-    void HideUi(TBool aSliderStatus);
+    void HideUi(TBool aHideSlider);
     
     /*
     * Sets the UI state
     */     
-    void SetUiSate (NGlxNFullScreenUIState::TUiState  aState);
+    void SetUiState (TUiState  aState);
     
     /*
     * returns the Ui state
     */     
-    NGlxNFullScreenUIState::TUiState GetUiSate();
+    TUiState GetUiState();
     
     /*
     * Call back function for the CPeriodic
@@ -282,7 +273,7 @@
     /**
      * Disable/enable the fullscreen toolbar
      */
-    void EnableFSToolbarL(TBool aEnable);
+    void EnableFSToolbar(TBool aEnable);
 
 private:
     /** Softkey resource id's */
@@ -313,7 +304,7 @@
     CGlxZoomControl* iZoomControl;
     
     // Holds the state of the Ui in Fullscreen
-    NGlxNFullScreenUIState::TUiState iUiState;
+    TUiState iUiState;
 
     // used to turn the Ui off,if the screen is inactive for 10 sec
     CPeriodic* iTimer;
@@ -341,6 +332,8 @@
 	TSize iGridIconSize; // grid icon size
     TBool iIsDialogLaunched;
     TBool iIsMMCRemoved;
+	CAlfEffectObserver* iAlfEffectObs;
+	TInt iEffectHandle;
     };
 
 #endif
@@ -203,21 +194,21 @@
     /*
     * Hide the UI off
-    * @param asliderstatus:When we start zooming using the slider widget,for continous zooming from the 
+    * @param aHideSlider:When we start zooming using the slider widget,for continous zooming from the 
     * fullscreen view to zoom control, we need to have the slider visible so in this case we shouldnt 
     * be hiding the slider so pass EFalse,else case asliderstatus = ETrue